******
Design
******

The *Product Image Attribute module* extends some concepts.

.. _model-product.image:

Product Image
=============

The *Product Image* concept is extended to store attributes from the set defined
on the product.
Those attributes are used to select for which variants the image applies.

.. seealso::

   The `Product Image <product_image:model-product.image>` concept is
   introduced by the :doc:`Product Image Module <product_image:index>`.
